==> tine20-tinebase_2016.11.24.tar.bz2: Addressbook/js/Addressbook-lang-it-debug.js <==
/********************** tine translations of Addressbook**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Addressbook'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: it\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Dati di contatto aziendali"

, "Organisation / Unit"
: "Organizzazione / Unità"

, "Business Address"
: "Indirizzo Aziendale"

, "Email"
: "Email"

, "Telephone Work"
: "Telefono Ufficio"

, "Telephone Cellphone"
: "Telefono Cellulare"

, "Telephone Car"
: "Telefono Automobile"

, "Telephone Fax"
: "Telefono Fax"

, "Telephone Page"
: "Pagina Telefono"

, "URL"
: "URL"

, "Role"
: "Ruolo"

, "Room"
: "Stanza"

, "Assistant"
: "Assistente"

, "Assistant Telephone"
: "Telefono Assistente"

, "Private Contact Data"
: "Dati di contatto personali"

, "Private Address"
: "Indirizzo Personale"

, "Email Home"
: "Email Personale"

, "Telephone Home"
: "Telefono Casa"

, "Telephone Cellphone Private"
: "Telefono Cellulare Privato"

, "Telephone Fax Home"
: "Telefono Fax Privato"

, "URL Home"
: "URL Privato"

, "Other Data"
: "Altri dati"

, "Birthday"
: "Compleanno"

, "Job Title"
: "Posizione Lavorativa"

, "Dear Mister"
: ""

, "Dear Miss"
: ""

, "Dear"
: ""

, "Mister"
: ""

, "Misses"
: ""

, "%s's personal addressbook"
: "Rubrica personale di %s"

, "Lists"
: "Liste"

, "List Roles"
: ""

, "manage shared addressbooks"
: "gestisci rubriche condivise"

, "Create new shared addressbook folders"
: "Crea una nuova rubrica condivisa"

, "manage shared addressbook favorites"
: "gestisci rubriche preferite condivise"

, "Create or update shared addressbook favorites"
: "Crea o modifica rubriche preferite condivise"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list roles in CoreData"
: ""

, "View, create, delete or update list roles in CoreData application"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "CardDAV URL"
: "URL CardDAV"

, "Contact, Contacts"
: [
  "Contatto"
 ,"Contatti"

]
, "List Role, , n); gettext("
: [
  ""
 ,""

]
, "Members"
: ""

, "Remove Member"
: ""

, "Map"
: "Mappa"

, "Personal Information"
: "Informazioni Personali"

, "Salutation"
: "Saluto"

, "Title"
: "Titolo"

, "First Name"
: "Nome"

, "Middle Name"
: "Secondo Nome"

, "Last Name"
: "Cognome"

, "Company"
: "Azienda"

, "Unit"
: "Unità"

, "Suffix"
: "Suffisso"

, "Job Role"
: "Ruolo aziendale"

, "Display Name"
: "Nome Visualizzato"

, "Contact Information"
: "Informazioni di contatto"

, "Phone"
: "Telefono"

, "Mobile"
: "Cellulare"

, "Fax"
: "Fax"

, "Phone (private)"
: "Telefono (privato)"

, "Mobile (private)"
: "Cellulare (privato)"

, "Fax (private)"
: "Fax (privato)"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (privata)"

, "Web"
: "Web"

, "Company Address"
: "Indirizzo Aziendale"

, "Street"
: "Via"

, "Street 2"
: "Via 2"

, "Region"
: "Provincia"

, "Postal Code"
: "CAP"

, "City"
: "Città"

, "Country"
: "Stato"

, "Description"
: "Descrizione"

, "Enter description"
: "Inserisci una descrizione"

, "Export as pdf"
: "Esporta come pdf"

, "Parse address"
: "Controlla indirizzo"

, "Paste address"
: "Incolla indirizzo"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "Fine della modalità token"

, "New Contact"
: "Nuovo Contatto"

, "Addressbook, Addressbooks"
: [
  "Rubrica"
 ,"Rubriche"

]
, "ID"
: ""

, "Name"
: "Nome"

, "Member of List"
: "Membro della lista"

, "Street (Company Address)"
: "Via (Indirizzo Aziendale)"

, "Street 2 (Company Address)"
: "Via 2 (Indirizzo Aziendale)"

, "City (Company Address)"
: "Città (Indirizzo Aziendale)"

, "Region (Company Address)"
: "Provincia (Indirizzo Aziendale)"

, "Postal Code (Company Address)"
: "CAP (Indirizzo Aziendale)"

, "Country (Company Address)"
: "Stato (Indirizzo Aziendale)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Via (Indirizzo Privato)"

, "Street 2 (Private Address)"
: "Via 2 (Indirizzo Privato)"

, "City (Private Address)"
: "Città (Indirizzo Privato)"

, "Region (Private Address)"
: "Provincia (Indirizzo Privato)"

, "Postal Code (Private Address)"
: "CAP (Indirizzo Privato)"

, "Country (Private Address)"
: "Stato (Indirizzo Privato)"

, "Company Communication"
: "Comunicazioni Aziendali"

, "Private Communication"
: "Comunicazioni Private"

, "Web (private)"
: "Web (privato)"

, "Contacts"
: "Contatti"

, "Addressbooks"
: "Rubriche"

, "User Account"
: "Account Utente"

, "Quick Search"
: "Ricerca veloce"

, "Type"
: "Tipo"

, "Last Modified Time"
: "Ultima data di modifica"

, "Last Modified By"
: "Ultima modifica da"

, "Creation Time"
: "Data di Creazione"

, "Created By"
: "Creato da"

, "List, Lists"
: [
  "Lista"
 ,"Liste"

]
, "Quick search"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Select list"
: ""

, "List type"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "List Information"
: ""

, "{0} must be given"
: ""

, "Company address"
: "Indirizzo aziendale"

, "Private address"
: "Indirizzo privato"

, "Select contact"
: "Seleziona contatti"

, "Private"
: "Privato"

, "Info"
: "Info"

, "Insecure link"
: "Link non sicuro"

, "Please review this link in edit dialog."
: "Per favore controlla questo Link nella pagina di modifica."

, "Export {0}, Export {0}"
: [
  "Esportato {0}"
 ,"Esportati {0}"

]
, "Export as PDF"
: "Esporta come PDF"

, "Export as CSV"
: "Esporta come CSV"

, "Export as ODS"
: "Esporta come ODS"

, "Export as XLS"
: "Esporta come XLS"

, "Export as DOC"
: ""

, "Export as ..."
: "Esporta come ..."

, "Import contacts"
: "Importa contatti"

, "Contact of a user account"
: "Contatto dell'account utente"

, "No name"
: ""

, "Tags"
: "Tag"

, "Full Name"
: "Nome Completo"

, "Postalcode"
: "CAP"

, "Street (private)"
: "Via (privato)"

, "City (private)"
: "Città (privato)"

, "Region (private)"
: "Regione (privato)"

, "Postalcode (private)"
: "CAP (privato)"

, "Country (private)"
: "Stato (privato)"

, "Car phone"
: "Telefono automobile"

, "Pager"
: "Cercapersone"

, "Email (private)"
: "Email (privata)"

, "URL (private)"
: "URL (privato)"

, "Note"
: "Note"

, "Timezone"
: "Fuso Orario"

, "Geo"
: "Geo"

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Uploaded new contact image."
: "Carica una nuova immagine per il contatto."

, "All contacts"
: "Tutti i contatti"

, "Default Addressbook"
: "Rubrica di default"

, "The default addressbook for new contacts"
: "Rubrica di default per i nuovi contatti"

, "Default Favorite"
: "Preferiti di default"

, "The default favorite which is loaded on addressbook startup"
: "Preferiti di default caricati all'avvio della rubrica"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "All Contacts"
: "Tutti i contatti"

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee)"
: ""

, "Contact duplicate check fields"
: "Contatto duplicato, controlla i campi"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Questi campi sono controllati quando viene creato un nuovo contatto. Se viene trovato un contatto con gli stessi dati verrà generata una eccezione di duplicazione."

, "Contact salutations available"
: "Saluto per i contatti disponibile"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Possibili saluti per i contatti. Fai attenzione, valori aggiuntivi possono avere effetto su altri sistemi di Rubrica in fase di esportazione o sincronizzazione."

, "Mr"
: "Sig."

, "Ms"
: "Sig.ra"

, "Parsing rules for addresses"
: "Controllo regole degli indirizzi"

, "Path to a XML file with address parsing rules."
: "Percorso del file XML con le regole di controllo degli indirizzi."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "Outlook 2007 CSV Tedesco"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Importa elenco (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Contatti importati da ###USERFULLNAME### - ###CURRENTTIME### ###CURRENTDATE###"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Importa contatti via CSV dalla rubrica Outlook"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importa contatti dalla rubrica di Google"

, "Contact CSV import from mac address book"
: "Importa contatti via CSV dalla rubrica mac"

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Importa contatti VCARD"

, "Internal Contacts"
: "Contatti Interni"

, "All contacts I have read grants for"
: "Tutti i contatti per cui ho il permesso di lettura"

, "My company"
: "Mia Azienda"

, "All coworkers in my company"
: "Tutti i colleghi nella mia azienda"

, "My contacts"
: "I miei contatti"

, "All contacts in my Addressbooks"
: "Tutti i contatti nella mia Rubrica"

, "Last modified by me"
: "Ultimi modificati da me"

, "All contacts that I have last modified"
: "Tutti i contatti che ho modificato"

, "Contact"
: "Contatto"

, "List Role"
: ""

, "Addressbook"
: "Rubrica"

, "List"
: "Lista"

, "Email Address"
: ""

, "Export {0}"
: "Esportato {0}"

}));

==> tine20-tinebase_2019.11.25.tar.bz2: Addressbook/js/Addressbook-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: it\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Dati di contatto aziendali"

, "Organisation / Unit"
: "Organizzazione / Unità"

, "Business Address"
: "Indirizzo Aziendale"

, "Email"
: "Email"

, "Telephone Work"
: "Telefono Ufficio"

, "Telephone Cellphone"
: "Telefono Cellulare"

, "Telephone Car"
: "Telefono Automobile"

, "Telephone Fax"
: "Telefono Fax"

, "Telephone Page"
: "Pagina Telefono"

, "URL"
: "URL"

, "Role"
: "Ruolo"

, "Room"
: "Stanza"

, "Assistant"
: "Assistente"

, "Assistant Telephone"
: "Telefono Assistente"

, "Private Contact Data"
: "Dati di contatto personali"

, "Private Address"
: "Indirizzo Personale"

, "Email Home"
: "Email Personale"

, "Telephone Home"
: "Telefono Casa"

, "Telephone Cellphone Private"
: "Telefono Cellulare Privato"

, "Telephone Fax Home"
: "Telefono Fax Privato"

, "URL Home"
: "URL Privato"

, "Other Data"
: "Altri dati"

, "Birthday"
: "Compleanno"

, "Job Title"
: "Posizione Lavorativa"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "Lista"
 ,"Liste"

]
, "Percent"
: ""

, "Description"
: "Descrizione"

, "Members"
: ""

, "Type"
: "Tipo"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "Rubrica"
 ,"Rubriche"

]
, "Contact, Contacts"
: [
  "Contatto"
 ,"Contatti"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Stato"

, "City"
: "Città"

, "Postalcode"
: "CAP"

, "Region"
: "Provincia"

, "Street"
: "Via"

, "Street 2"
: "Via 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Stato (privato)"

, "City (private)"
: "Città (privato)"

, "Postalcode (private)"
: "CAP (privato)"

, "Region (private)"
: "Regione (privato)"

, "Street (private)"
: "Via (privato)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Email (privata)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geo"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Note"

, "Last Name"
: "Cognome"

, "Display Name"
: "Nome Visualizzato"

, "Full Name"
: "Nome Completo"

, "First Name"
: "Nome"

, "Middle Name"
: "Secondo Nome"

, "Title"
: "Titolo"

, "Suffix"
: "Suffisso"

, "Company"
: "Azienda"

, "Unit"
: "Unità"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Ruolo aziendale"

, "Salutation"
: "Saluto"

, "syncBackendIds"
: ""

, "Car phone"
: "Telefono automobile"

, "Mobile"
: "Cellulare"

, "Mobile (private)"
: "Cellulare (privato)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (privato)"

, "Phone (private)"
: "Telefono (privato)"

, "Pager"
: "Cercapersone"

, "Phone"
: "Telefono"

, "Timezone"
: "Fuso Orario"

, "Web"
: "Web"

, "URL (private)"
: "URL (privato)"

, "Label"
: ""

, "Lists"
: "Liste"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Informazioni di contatto"

, "Company Address"
: "Indirizzo Aziendale"

, "New Contact"
: "Nuovo Contatto"

, "ID"
: ""

, "Name"
: "Nome"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Importa contatti"

, "Contact of a user account"
: "Contatto dell'account utente"

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Privato"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Tag"

, "List Roles"
: ""

, "Street (Company Address)"
: "Via (Indirizzo Aziendale)"

, "Street 2 (Company Address)"
: "Via 2 (Indirizzo Aziendale)"

, "City (Company Address)"
: "Città (Indirizzo Aziendale)"

, "Region (Company Address)"
: "Provincia (Indirizzo Aziendale)"

, "Postal Code (Company Address)"
: "CAP (Indirizzo Aziendale)"

, "Country (Company Address)"
: "Stato (Indirizzo Aziendale)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Via (Indirizzo Privato)"

, "Street 2 (Private Address)"
: "Via 2 (Indirizzo Privato)"

, "City (Private Address)"
: "Città (Indirizzo Privato)"

, "Region (Private Address)"
: "Provincia (Indirizzo Privato)"

, "Postal Code (Private Address)"
: "CAP (Indirizzo Privato)"

, "Country (Private Address)"
: "Stato (Indirizzo Privato)"

, "Company Communication"
: "Comunicazioni Aziendali"

, "Private Communication"
: "Comunicazioni Private"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (privata)"

, "Web (private)"
: "Web (privato)"

, "Contacts"
: "Contatti"

, "Addressbooks"
: "Rubriche"

, "User Account"
: "Account Utente"

, "Quick Search"
: "Ricerca veloce"

, "Postal Code"
: "CAP"

, "Last Modified Time"
: "Ultima data di modifica"

, "Last Modified By"
: "Ultima modifica da"

, "Creation Time"
: "Data di Creazione"

, "Created By"
: "Creato da"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Inserisci una descrizione"

, "{0} must be given"
: ""

, "Member of List"
: "Membro della lista"

, "Map"
: "Mappa"

, "Company address"
: "Indirizzo aziendale"

, "Private address"
: "Indirizzo privato"

, "CardDAV URL"
: "URL CardDAV"

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Informazioni Personali"

, "Parse address"
: "Controlla indirizzo"

, "Print contact"
: ""

, "Paste address"
: "Incolla indirizzo"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "Fine della modalità token"

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "Tutti i contatti"

, "Default Addressbook"
: "Rubrica di default"

, "The default addressbook for new contacts"
: "Rubrica di default per i nuovi contatti"

, "Default Favorite"
: "Preferiti di default"

, "The default favorite which is loaded on addressbook startup"
: "Preferiti di default caricati all'avvio della rubrica"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: "Tutti i contatti"

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Contatto duplicato, controlla i campi"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Questi campi sono controllati quando viene creato un nuovo contatto. Se viene trovato un contatto con gli stessi dati verrà generata una eccezione di duplicazione."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Saluto per i contatti disponibile"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Possibili saluti per i contatti. Fai attenzione, valori aggiuntivi possono avere effetto su altri sistemi di Rubrica in fase di esportazione o sincronizzazione."

, "Mr"
: "Sig."

, "Ms"
: "Sig.ra"

, "Parsing rules for addresses"
: "Controllo regole degli indirizzi"

, "Path to a XML file with address parsing rules."
: "Percorso del file XML con le regole di controllo degli indirizzi."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Importa contatti VCARD"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Importa elenco (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Contatti importati da ###USERFULLNAME### - ###CURRENTTIME### ###CURRENTDATE###"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "Outlook 2007 CSV Tedesco"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Importa contatti via CSV dalla rubrica Outlook"

, "Contact CSV import from mac address book"
: "Importa contatti via CSV dalla rubrica mac"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importa contatti dalla rubrica di Google"

, "manage shared addressbooks"
: "gestisci rubriche condivise"

, "Create new shared addressbook folders"
: "Crea una nuova rubrica condivisa"

, "manage shared addressbook favorites"
: "gestisci rubriche preferite condivise"

, "Create or update shared addressbook favorites"
: "Crea o modifica rubriche preferite condivise"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "Rubrica personale di %s"

, "All contacts I have read grants for"
: "Tutti i contatti per cui ho il permesso di lettura"

, "My company"
: "Mia Azienda"

, "All coworkers in my company"
: "Tutti i colleghi nella mia azienda"

, "My contacts"
: "I miei contatti"

, "All contacts in my Addressbooks"
: "Tutti i contatti nella mia Rubrica"

, "Last modified by me"
: "Ultimi modificati da me"

, "All contacts that I have last modified"
: "Tutti i contatti che ho modificato"

, "Internal Contacts"
: "Contatti Interni"
, ""
: "Project-Id-Version: Tine 2.0 - GDPR\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: Italian\nX-Poedit-Country: \nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Data provenances"
: ""

, "Data intended purposes"
: ""

, "Show expired"
: ""

, "Data Provenance"
: ""

, "Reason for Editing"
: ""

, "Please enter the reason for editing this data"
: ""

, "Please Confirm the Data Provenance"
: ""

, "GDPR"
: ""

, "Must not be contacted"
: ""

, "This Contact withdrawed usage of his data for any purpose."
: ""

, "Blacklist"
: ""

, "GDPR Intended Purpose"
: ""

, "GDPR Blacklisted"
: ""

, "GDPR Data Provenance"
: ""

, "GDPR Data Editing Reason"
: ""

, "Data provenance for ADB contacts mandatory"
: ""

, "Whether the data provenance for ADB contacts is mandatory, not mandatory or empty provenances will be set to a default"
: ""

, "yes"
: ""

, "no"
: ""

, "default"
: ""

, "Default data provenance for ADB contacts"
: ""

, "Data intended purpose, Data intended purposes"
: [
  ""
 ,""

]
, "Agreement date"
: ""

, "Agreement comment"
: ""

, "Withdraw date"
: ""

, "Withdraw comment"
: ""

, "Data provenance, Data provenances"
: [
  ""
 ,""

]
, "Expiration"
: ""

, "Manage data provenances in CoreData"
: ""

, "View, create, delete or update data provenances in CoreData application"
: ""

, "Manage data intended purposes in CoreData"
: ""

, "View, create, delete or update data intended purposes in CoreData application"
: ""

, "List"
: "Lista"

, "Addressbook"
: "Rubrica"

, "Contact"
: "Contatto"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

, "Data intended purpose"
: ""

, "Data provenance"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
